.. include:: ../../references.txt

.. _pigs:

****
PIGs
****

PIGs (proposals for improvement of Gammapy) are short documents proposing a
major addition or change to Gammapy. See :ref:`pig-001` for further information.

Below is a list of merged PIGs, i.e. the ones that are finalised, with status
"accepted" or "rejected" or "withdrawn". The ones with "draft" status, i.e. that
are under discussion, can be found on Github as `pull requests with the "pig"
label`_ .

.. toctree::
    :maxdepth: 1

    pig-001
    pig-002
    pig-003
    pig-004
    pig-005
    pig-006
    pig-007
    pig-008
    pig-009
    pig-010
    pig-011
    pig-012
    pig-013
    pig-014
    pig-016
    pig-018

.. _pull requests with the "pig" label: https://github.com/gammapy/gammapy/issues?q=label%3Apig
